@@ -48,13 +48,15 @@
 #include <KActionCollection>
 #include <KConfigGroup>
 #include <KGuiItem>
+#include <KIO/ApplicationLauncherJob>
 #include <KIO/Job>
+#include <KIO/JobUiDelegate>
+#include <KIO/OpenUrlJob>
 #include <KJobWidgets>
 #include <KIO/StatJob>
 #include <KMessageBox>
 #include <KParts/OpenUrlArguments>
 #include <KPluginFactory>
-#include <KRun>
 #include <KStandardGuiItem>
 #include <KToggleAction>
 #include <KLocalizedString>
@@ -264,7 +266,7 @@ void Part::registerJob(KJob* job)
     KIO::getJobTracker()->registerJob(job);
     m_jobTracker->registerJob(job);
 
-    emit busy();
+    Q_EMIT busy();
     connect(job, &KJob::result, this, &Part::ready);
 }
 
@@ -278,38 +280,44 @@ void Part::extractSelectedFilesTo(const QString& localPath)
     }
 
     const QUrl url = QUrl::fromUserInput(localPath, QString());
-    KIO::StatJob* statJob = nullptr;
 
-    // Try to resolve the URL to a local path.
+    auto doExtract = [this](const QString &destination) {
+        qCDebug(ARK) << "Extract to" << destination;
+
+        Kerfuffle::ExtractionOptions options;
+        options.setDragAndDropEnabled(true);
+
+        // Create and start the ExtractJob.
+        ExtractJob *job = m_model->extractFiles(filesAndRootNodesForIndexes(addChildren(getSelectedIndexes())), destination, options);
+        registerJob(job);
+        connect(job, &KJob::result, this, &Part::slotExtractionDone);
+        job->start();
+    };
+
     if (!url.isLocalFile() && !url.scheme().isEmpty()) {
-        statJob = KIO::mostLocalUrl(url);
+        // Try to resolve the URL to a local path.
+        KIO::StatJob *statJob = KIO::mostLocalUrl(url);
 
-        if (!statJob->exec() || statJob->error() != 0) {
-            return;
-        }
-    }
+        connect(statJob, &KJob::result, this, [=]() {
+            if (statJob->error()) {
+                KMessageBox::error(widget(), statJob->errorString());
+                return;
+            }
 
-    const QString destination = statJob ? statJob->statResult().stringValue(KIO::UDSEntry::UDS_LOCAL_PATH) : localPath;
-    delete statJob;
+            const QString udsLocalPath = statJob->statResult().stringValue(KIO::UDSEntry::UDS_LOCAL_PATH);
+            if (udsLocalPath.isEmpty()) { // The URL could not be resolved to a local path
+                qCWarning(ARK) << "Ark cannot extract to non-local destination:" << localPath;
+                KMessageBox::sorry(widget(), xi18nc("@info", "Ark can extract archives to local destinations only."));
+                return;
+            }
+
+            doExtract(udsLocalPath);
+        });
 
-    // The URL could not be resolved to a local path.
-    if (!url.isLocalFile() && destination.isEmpty()) {
-        qCWarning(ARK) << "Ark cannot extract to non-local destination:" << localPath;
-        KMessageBox::sorry(widget(), xi18nc("@info", "Ark can only extract to local destinations."));
         return;
     }
 
-    qCDebug(ARK) << "Extract to" << destination;
-
-    Kerfuffle::ExtractionOptions options;
-    options.setDragAndDropEnabled(true);
-
-    // Create and start the ExtractJob.
-    ExtractJob *job = m_model->extractFiles(filesAndRootNodesForIndexes(addChildren(getSelectedIndexes())), destination, options);
-    registerJob(job);
-    connect(job, &KJob::result,
-            this, &Part::slotExtractionDone);
-    job->start();
+    doExtract(localPath);
 }
 
 void Part::guiActivateEvent(KParts::GUIActivateEvent *event)
@@ -357,7 +365,8 @@ void Part::setupActions()
     connect(m_showInfoPanelAction, &QAction::triggered,
             this, &Part::slotToggleInfoPanel);
 
-    m_saveAsAction = KStandardAction::saveAs(this, &Part::slotSaveAs, nullptr);
+    m_saveAsAction = KStandardAction::saveAs(this, &Part::slotSaveAs, this);
+    m_saveAsAction->setText(i18nc("@action:inmenu", "Save Copy As..."));
     actionCollection()->addAction(QStringLiteral("ark_file_save_as"), m_saveAsAction);
 
     m_openFileAction = actionCollection()->addAction(QStringLiteral("openfile"));
@@ -586,7 +595,7 @@ void Part::createArchive()
     const QString fixedMimeType = arguments().metaData()[QStringLiteral("fixedMimeType")];
     m_model->createEmptyArchive(localFilePath(), fixedMimeType, m_model);
 
-    if (arguments().metaData().contains(QLatin1String("volumeSize"))) {
+    if (arguments().metaData().contains(QStringLiteral("volumeSize"))) {
         m_model->archive()->setMultiVolume(true);
     }
 
@@ -742,16 +751,16 @@ QModelIndexList Part::getSelectedIndexes()
 void Part::readCompressionOptions()
 {
     // Store options from CreateDialog if they are set.
-    if (!m_compressionOptions.isCompressionLevelSet() && arguments().metaData().contains(QLatin1String("compressionLevel"))) {
+    if (!m_compressionOptions.isCompressionLevelSet() && arguments().metaData().contains(QStringLiteral("compressionLevel"))) {
         m_compressionOptions.setCompressionLevel(arguments().metaData()[QStringLiteral("compressionLevel")].toInt());
     }
-    if (m_compressionOptions.compressionMethod().isEmpty() && arguments().metaData().contains(QLatin1String("compressionMethod"))) {
+    if (m_compressionOptions.compressionMethod().isEmpty() && arguments().metaData().contains(QStringLiteral("compressionMethod"))) {
         m_compressionOptions.setCompressionMethod(arguments().metaData()[QStringLiteral("compressionMethod")]);
     }
-    if (m_compressionOptions.encryptionMethod().isEmpty() && arguments().metaData().contains(QLatin1String("encryptionMethod"))) {
+    if (m_compressionOptions.encryptionMethod().isEmpty() && arguments().metaData().contains(QStringLiteral("encryptionMethod"))) {
         m_compressionOptions.setEncryptionMethod(arguments().metaData()[QStringLiteral("encryptionMethod")]);
     }
-    if (!m_compressionOptions.isVolumeSizeSet() && arguments().metaData().contains(QLatin1String("volumeSize"))) {
+    if (!m_compressionOptions.isVolumeSizeSet() && arguments().metaData().contains(QStringLiteral("volumeSize"))) {
         m_compressionOptions.setVolumeSize(arguments().metaData()[QStringLiteral("volumeSize")].toULong());
     }
 
@@ -915,12 +924,12 @@ void Part::slotLoadingStarted()
 void Part::slotLoadingFinished(KJob *job)
 {
     if (!job->error()) {
-        emit completed();
+        Q_EMIT completed();
         return;
     }
 
     // Loading failed or was canceled by the user (e.g. password dialog rejected).
-    emit canceled(job->errorString());
+    Q_EMIT canceled(job->errorString());
     resetArchive();
 
     if (job->error() != KJob::KilledJobError) {
@@ -963,7 +972,7 @@ void Part::setFileNameFromArchive()
     m_infoPanel->setPrettyFileName(prettyName);
     m_infoPanel->updateWithDefaults();
 
-    emit setWindowCaption(prettyName);
+    Q_EMIT setWindowCaption(prettyName);
 }
 
 void Part::slotOpenEntry(int mode)
@@ -1029,13 +1038,18 @@ void Part::slotOpenExtractedEntry(KJob *job)
             QFile::setPermissions(fullName, QFileDevice::ReadOwner | QFileDevice::ReadGroup | QFileDevice::ReadOther);
         }
 
+        const QUrl url = QUrl::fromUserInput(fullName, QString(), QUrl::AssumeLocalFile);
         if (qobject_cast<OpenWithJob*>(job)) {
-            const QList<QUrl> urls = {QUrl::fromUserInput(fullName, QString(), QUrl::AssumeLocalFile)};
-            KRun::displayOpenWithDialog(urls, widget());
+            // Constructing an ApplicationLauncherJob without an argument will
+            // trigger the openWith dialog
+            KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob();
+            job->setUrls({url});
+            job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, widget()));
+            job->start();
         } else {
-            KRun::runUrl(QUrl::fromUserInput(fullName, QString(), QUrl::AssumeLocalFile),
-                         QMimeDatabase().mimeTypeForFile(fullName).name(),
-                         widget(), KRun::RunFlags());
+            KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url);
+            job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, widget()));
+            job->start();
         }
     } else if (job->error() != KJob::KilledJobError) {
         KMessageBox::error(widget(), job->errorString());
@@ -1261,11 +1275,13 @@ void Part::slotExtractionDone(KJob* job)
             QUrl destinationDirectory = QUrl::fromLocalFile(extractJob->destinationDirectory()).adjusted(QUrl::NormalizePathSegments);
             qCDebug(ARK) << "Shall open URL" << destinationDirectory;
 
-            KRun::runUrl(destinationDirectory, QStringLiteral("inode/directory"), widget(), KRun::RunExecutables, QString(), QByteArray());
+            KIO::OpenUrlJob *job = new KIO::OpenUrlJob(destinationDirectory, QStringLiteral("inode/directory"));
+            job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, widget()));
+            job->start();
         }
 
         if (ArkSettings::closeAfterExtraction()) {
-           emit quit();
+           Q_EMIT quit();
         }
     }
 }
@@ -1647,44 +1663,33 @@ void Part::slotToggleInfoPanel(bool visible)
 
 void Part::slotSaveAs()
 {
-    QUrl saveUrl = QFileDialog::getSaveFileUrl(widget(), i18nc("@title:window", "Save Archive As"), url());
+    const QUrl srcUrl = url();
+    const QUrl saveUrl = QFileDialog::getSaveFileUrl(widget(), i18nc("@title:window", "Save Copy As"), srcUrl);
 
-    if ((saveUrl.isValid()) && (!saveUrl.isEmpty())) {
-        auto statJob = KIO::stat(saveUrl, KIO::StatJob::DestinationSide, 0);
-        KJobWidgets::setWindow(statJob, widget());
-        if (statJob->exec()) {
-            int overwrite = KMessageBox::warningContinueCancel(widget(),
-                                                               xi18nc("@info", "An archive named <filename>%1</filename> already exists. Are you sure you want to overwrite it?", saveUrl.fileName()),
-                                                               QString(),
-                                                               KStandardGuiItem::overwrite());
-
-            if (overwrite != KMessageBox::Continue) {
-                return;
-            }
-        }
-
-        QUrl srcUrl = QUrl::fromLocalFile(localFilePath());
-
-        if (!QFile::exists(localFilePath())) {
-            if (url().isLocalFile()) {
-                KMessageBox::error(widget(),
-                                   xi18nc("@info", "The archive <filename>%1</filename> cannot be copied to the specified location. The archive does not exist anymore.", localFilePath()));
-
-                return;
-            } else {
-                srcUrl = url();
-            }
-        }
-
-        KIO::Job *copyJob = KIO::file_copy(srcUrl, saveUrl, -1, KIO::Overwrite);
-
-        KJobWidgets::setWindow(copyJob, widget());
-        copyJob->exec();
-        if (copyJob->error()) {
-            KMessageBox::error(widget(),
-                               xi18nc("@info", "The archive could not be saved as <filename>%1</filename>. Try saving it to another location.", saveUrl.path()));
-        }
+    if (saveUrl.isEmpty()) { // If the user selected "cancel" the returned url is empty
+        return;
     }
+
+    KIO::Job *copyJob = KIO::file_copy(srcUrl, saveUrl, -1, KIO::Overwrite);
+    KJobWidgets::setWindow(copyJob, widget());
+    connect(copyJob, &KJob::result, this, [this, copyJob, srcUrl, saveUrl]() {
+        const int err = copyJob->error();
+        if (err) {
+            QString msg = copyJob->errorString();
+            // Use custom error messages for these two cases, otherwise just use KIO's
+            if (err == KIO::ERR_WRITE_ACCESS_DENIED) {
+                msg = xi18nc("@info",
+                            "The archive could not be saved as <filename>%1</filename>. Try saving"
+                            " it to another location.", saveUrl.toDisplayString(QUrl::PreferLocalFile));
+            } else if (err == KIO::ERR_DOES_NOT_EXIST) {
+                msg = xi18nc("@info",
+                            "The archive <filename>%1</filename> does not exist anymore, therefore it"
+                            " cannot be copied to the specified location.", srcUrl.toDisplayString(QUrl::PreferLocalFile));
+            }
+
+            KMessageBox::error(widget(), msg);
+        }
+    });
 }
 
 void Part::slotShowContextMenu()
